@@ -1,5 +1,4 @@
 
-
 #' @rdname chop_quantiles
 #'
 #' @export
@@ -42,10 +41,10 @@ brk_quantiles <- function (probs, ...) {
 }
 
 
-#' @rdname chop_quantiles
+#' @rdname chop_equally
 #'
 #' @export
-#' @order 3
+#' @order 2
 brk_equally <- function (groups) {
   assert_that(is.count(groups))
   brk_quantiles(seq(0, groups)/groups)
@@ -55,25 +54,35 @@ brk_equally <- function (groups) {
 #' @rdname chop_mean_sd
 #' @export
 #' @order 2
-brk_mean_sd <- function (sd = 3) {
-  assert_that(is.number(sd), sd > 0)
+#' @importFrom lifecycle deprecated
+brk_mean_sd <- function (sds = 1:3, sd = deprecated()) {
+  if (lifecycle::is_present(sd)) {
+    lifecycle::deprecate_soft(
+            when = "0.7.0",
+            what = "brk_mean_sd(sd)",
+            with = "brk_mean_sd(sds = 'vector of sds')"
+          )
+    assert_that(is.number(sd), sd > 0)
+    # we start from 0 but remove the 0
+    # this works for e.g. sd = 0.5, whereas seq(1L, sd, 1L) would not:
+    sds <- seq(0L, sd, 1L)[-1]
+    if (! sd %in% sds) sds <- c(sds, sd)
+  }
+
+  assert_that(is.numeric(sds), all(sds > 0))
 
   function (x, extend, left, close_end) {
-    x_m <- mean(x, na.rm = TRUE)
-    x_sd <- sd(x, na.rm = TRUE)
+    x_mean <- mean(x, na.rm = TRUE)
+    x_sd <- stats::sd(x, na.rm = TRUE)
 
-    if (is.na(x_m) || is.na(x_sd) || x_sd == 0) {
+    if (is.na(x_mean) || is.na(x_sd) || x_sd == 0) {
       return(empty_breaks())
     }
 
-    # work out the "sds" first, then scale them by mean and sd
-    sds_plus <- seq(0, sd, 1L)
-    if (! sd %in% sds_plus) sds_plus <- c(sds_plus, sd)
-    sds_minus <- -1 * sds_plus[-1]
-    sds_minus <- sort(sds_minus)
-    sds <- c(sds_minus, sds_plus)
-
-    breaks <- sds * x_sd + x_m
+    # add negative sds, then scale them by mean and sd
+    sds <- sort(sds)
+    sds <- c(-rev(sds), 0, sds)
+    breaks <- sds * x_sd + x_mean
     breaks <- create_lr_breaks(breaks, left, close_end)
 
     needs <- needs_extend(breaks, x, extend)
@@ -90,7 +99,7 @@ brk_mean_sd <- function (sd = 3) {
 
 #' Equal-width intervals for dates or datetimes
 #'
-#' `brk_width` can be used with time interval classes from base R or the
+#' `brk_width()` can be used with time interval classes from base R or the
 #' `lubridate` package.
 #'
 #' @param width A scalar [difftime], [Period][lubridate::Period-class] or
@@ -100,7 +109,7 @@ brk_mean_sd <- function (sd = 3) {
 #'   Can be omitted.
 #'
 #' @details
-#' If `width` is a Period, [`lubridate::add_with_rollback()`][lubridate::mplus]
+#' If `width` is a Period, [`lubridate::add_with_rollback()`][`lubridate::m+`]
 #' is used to calculate the widths. This can be useful for e.g. calendar months.
 #'
 #' @examples
@@ -114,6 +123,7 @@ brk_mean_sd <- function (sd = 3) {
 #' @name brk_width-for-datetime
 NULL
 
+
 #' @rdname chop_width
 #' @export
 #' @order 2
@@ -144,9 +154,9 @@ brk_width.default <- function (width, start) {
     max_x    <- quiet_max(x[is.finite(x)])
 
     if (sm) {
-      start <- if (width > 0) min_x else max_x
+      start <- if (sign(width) > 0) min_x else max_x
     }
-    until <- if (width > 0) max_x else min_x
+    until <- if (sign(width) > 0) max_x else min_x
 
     if (is.finite(start) && is.finite(until)) {
       breaks <- sequence_width(width, start, until)
@@ -154,7 +164,7 @@ brk_width.default <- function (width, start) {
       return(empty_breaks())
     }
 
-    if (width <= 0) breaks <- rev(breaks)
+    if (sign(width) <= 0) breaks <- rev(breaks)
 
     breaks <- create_lr_breaks(breaks, left, close_end)
     breaks <- maybe_extend(breaks, x, extend)
@@ -181,7 +191,7 @@ sequence_width <- function(width, start, until) {
 sequence_width.default <- function (width, start, until) {
   breaks <- seq(start, until, width)
 
-  too_short <- if (width > 0) {
+  too_short <- if (sign(width) > 0) {
     breaks[length(breaks)] < until
   } else {
     breaks[length(breaks)] > until
@@ -226,7 +236,7 @@ sequence_width.Period <- function(width, start, until) {
 }
 
 
-#' @rdname chop_width
+#' @rdname chop_evenly
 #' @export
 #' @order 2
 brk_evenly <- function(intervals) {
@@ -235,7 +245,7 @@ brk_evenly <- function(intervals) {
   function (x, extend, left, close_end) {
     min_x <- quiet_min(x[is.finite(x)])
     max_x <- quiet_max(x[is.finite(x)])
-    if (max_x - min_x <= 0) return(empty_breaks())
+    if (sign(max_x - min_x) <= 0) return(empty_breaks())
 
     breaks <- seq(min_x, max_x, length.out = intervals + 1L)
     breaks <- create_lr_breaks(breaks, left, close_end)
@@ -267,72 +277,6 @@ brk_n <- function (n) {
 }
 
 
-#' @param breaks A numeric vector.
-#' @name breaks-doc
-#' @return A (function which returns an) object of class `breaks`.
-NULL
-
-
-#' Left- or right-closed breaks
-#'
-#' \lifecycle{questioning}
-#'
-#' These functions are in the "questioning" stage because they clash with the
-#' `left` argument to [chop()] and friends.
-#'
-#' @inherit breaks-doc params return
-#'
-#' @name brk-left-right
-#'
-#' @details
-#' These functions override the `left` argument of [chop()].
-#'
-#' @examples
-#' chop(5:7, brk_left(5:7))
-#'
-#' chop(5:7, brk_right(5:7))
-#'
-#' chop(5:7, brk_left(5:7))
-#'
-NULL
-
-
-#' @export
-#' @rdname brk-left-right
-brk_left <- function (breaks) {
-  if (is.function(breaks)) {
-    lifecycle::deprecate_stop("0.4.0", "brk_left.function()",
-          details = "Please use the `left` argument to `chop()` instead.")
-  }
-  assert_that(noNA(breaks))
-  breaks <- sort(breaks)
-
-  function(x, extend, left, close_end) {
-    if (! left) warning("`left` argument to `brk_left()` ignored")
-    breaks <- create_lr_breaks(breaks, left = TRUE, close_end)
-    maybe_extend(breaks, x, extend)
-  }
-}
-
-
-#' @export
-#' @rdname brk-left-right
-brk_right <- function (breaks) {
-  if (is.function(breaks)) {
-    lifecycle::deprecate_stop("0.4.0", "brk_right.function()",
-      details = "Please use the `left` argument to `chop()` instead.")
-  }
-  assert_that(noNA(breaks))
-  breaks <- sort(breaks)
-
-  function (x, extend, left, close_end) {
-    if (left) warning("`left` argument to `brk_right()` ignored")
-    breaks <- create_lr_breaks(breaks, left = FALSE, close_end)
-    maybe_extend(breaks, x, extend)
-  }
-}
-
-
 #' Create a standard set of breaks
 #'
 #' @inherit breaks-doc params return
@@ -345,7 +289,6 @@ brk_right <- function (breaks) {
 #'
 brk_default <- function (breaks) {
   assert_that(noNA(breaks))
-  breaks <- sort(breaks)
 
   function (x, extend, left, close_end) {
     breaks <- create_lr_breaks(breaks, left, close_end)
@@ -354,6 +297,12 @@ brk_default <- function (breaks) {
 }
 
 
+#' @param breaks A numeric vector.
+#' @name breaks-doc
+#' @return A (function which returns an) object of class `breaks`.
+NULL
+
+
 #' Create a `breaks` object manually
 #'
 #' @param breaks A vector, which must be sorted.
@@ -373,8 +322,8 @@ brk_default <- function (breaks) {
 #' [ 1,  2 ] ( 2, 3 )
 #' }
 #'
-#' Singleton breaks are created by repeating a number in `breaks`.
-#' Singletons must be closed on both sides, so if there is a repeated number
+#' Singleton breaks are created by repeating a number in `breaks`. Singletons
+#' must be closed on both sides, so if there is a repeated number
 #' at indices `i`, `i+1`, `left[i]` *must* be `TRUE` and `left[i+1]` must be
 #' `FALSE`.
 #'
