@@ -1,22 +1,27 @@
 
 
 #' @name chop-doc
-#' @param x A vector.
-#' @param breaks,labels,left,...,close_end  Passed to [chop()].
+#' @param ... Passed to [chop()].
 #' @return
-#' For  `chop_*` functions, a factor of the same length as `x`.
+#' `chop_*` functions return a [`factor`] of the same length as `x`.
+#'
+#' `brk_*` functions return a [`function`] to create `breaks`.
+#'
+#' `tab_*` functions return a contingency [table()].
 NULL
 
 
 #' Cut data into intervals
 #'
-#' `chop` cuts `x` into intervals. It returns a factor of the same
-#' length as `x`, representing which interval contains each element of `x`.
-#'
+#' `chop()` cuts `x` into intervals. It returns a [`factor`] of the same length as
+#' `x`, representing which interval contains each element of `x`.
+#' `kiru()` is an alias for `chop`.
+#' `tab()` calls `chop()` and returns a contingency [table()] from the result.
 #'
 #' @param x A vector.
-#' @param breaks See below.
-#' @param labels See below.
+#' @param breaks A numeric vector of cut-points or a function to create
+#'   cut-points from `x`.
+#' @param labels A character vector of labels or a function to create labels.
 #' @param extend Logical. Extend breaks to `+/-Inf`?
 #' @param left Logical. Left-closed breaks?
 #' @param close_end Logical. Close last break at right? (If `left` is `FALSE`,
@@ -25,7 +30,9 @@ NULL
 #'
 #' @details
 #'
-#' `x` may be numeric, or a [Date or Date-Time][[DateTimeClasses].
+#' `x` may be numeric, or a [Date or Date-Time][DateTimeClasses].
+#'
+#' ## Breaks
 #'
 #' `breaks` may be a numeric vector or a function.
 #'
@@ -33,30 +40,32 @@ NULL
 #' singleton intervals. For example `breaks = c(1, 3, 3, 5)` creates 3
 #' intervals: \code{[1, 3)}, \code{{3}} and \code{(3, 5]}.
 #'
+#' If `breaks` is a function it is called with the `x`, `extend`, `left` and
+#' `close_end` arguments, and should return an object of class `breaks`.
+#' Use `brk_*` functions in this context, to create a variety of data-dependent
+#' breaks.
+#'
+#' ## Options for breaks
+#'
 #' By default, left-closed intervals are created. If `left` is `FALSE`, right-
 #' closed intervals are created.
 #'
 #' If `close_end` is `TRUE` the end break will be closed at both ends, ensuring
 #' that all values `y` with `min(x) <= y <= max(x)` are included in the default
-#' intervals. That is:
+#' intervals.
+#'
+#' Overall:
 #'
 #' * If `left` is `TRUE` and `close_end` is `TRUE`, breaks will look like
-#'   `[x1, x2), [x2, x3) ... [x_n-1, x_n]`.
+#'   \code{[x1, x2), [x2, x3) ... [x_n-1, x_n]}.
 #' * If `left` is `FALSE` and `close_end` is `TRUE`, breaks will look like
-#'    `[x1, x2], (x2, x3] ... (x_n-1, x_n]`.
+#'    \code{[x1, x2], (x2, x3] ... (x_n-1, x_n]}.
 #' * If `left` is `TRUE` and `close_end` is `FALSE`, all breaks will look like
-#'    `...[x1, x2) ...`
+#'   \code{...[x1, x2) ...}.
 #' * If `left` is `FALSE` and `close_end` is `FALSE`, all breaks will look like
-#'    `...(x1, x2] ...`
+#'   \code{...(x1, x2] ...}.
 #'
-#' If `breaks` is a function it is called with the `x`, `extend`, `left` and
-#' `close_end` arguments, and should return an object of class `breaks`.
-#' Use `brk_` functions in this context, to create a variety of data-dependent
-#' breaks.
-#'
-#' `labels` may be a character vector. It should have the same length as the
-#' number of intervals. Alternatively, use a `lbl_` function such as
-#' [lbl_seq()].
+#' ## Extending intervals
 #'
 #' If `extend` is `TRUE`, intervals will be extended to \code{[-Inf,
 #' min(breaks))} and \code{(max(breaks), Inf]}.
@@ -66,34 +75,52 @@ NULL
 #' necessary -- i.e. if `min(x) < min(breaks)` and `max(x) > max(breaks)`
 #' respectively.
 #'
-#' Extending intervals, either by `extend = NULL` or `extend = FALSE`,
+#' Extending intervals, either by `extend = NULL` or `extend = TRUE`,
 #' *always* leaves the central, non-extended intervals unchanged. In particular,
 #' `close_end` applies to the central intervals, not to the extended ones.
 #' For example, if `breaks = c(1, 3, 5)` and `close_end = TRUE`, the resulting
 #' breaks will be
 #'
-#' `[1, 3), [3, 5]`
+#' \code{[1, 3), [3, 5]}
 #'
-#' and if they are extended on both ends the result will be e.g.
+#' and if `extend = TRUE` the result will be
 #'
-#' `[-Inf, 1), [1, 3), [3, 5], (5, Inf]`
+#' \code{[-Inf, 1), [1, 3), [3, 5], (5, Inf]}
 #'
-#' `NA` values in `x`, and values which are outside the (extended) endpoints,
+#'
+#' ## Labels
+#'
+#' `labels` may be a character vector. It should have the same length as the
+#' number of intervals. Alternatively, use a `lbl_*` function such as
+#' [lbl_seq()].
+#'
+#' If `labels` is `NULL`, then integer codes will be returned instead of a
+#' factor.
+#'
+#' ## Miscellaneous
+#'
+#' `NA` values in `x`, and values which are outside the extended endpoints,
 #' return `NA`.
 #'
-#' Note that `chop`, like all of R, uses binary arithmetic. Thus, numbers may
+#' `kiru()` is a synonym for `chop()`. If you load `{tidyr}`, you can use it to
+#' avoid confusion with `tidyr::chop()`.
+#'
+#' Note that `chop()`, like all of R, uses binary arithmetic. Thus, numbers may
 #' not be exactly equal to what you think they should be. There is an example
 #' below.
 #'
 #' @return
-#' A [factor] of the same length as `x`, representing the intervals containing
-#' the value of `x`.
+#' `chop()` returns a [`factor`] of the same length as `x`, representing the
+#' intervals containing the value of `x`.
+#'
+#' `tab()` returns a contingency [table()].
 #'
 #' @export
 #'
 #' @family chopping functions
 #'
-#' @seealso cut
+#' @seealso [base::cut()], [`non-standard-types`] for chopping objects that
+#'   aren't numbers.
 #'
 #' @examples
 #' chop(1:3, 2)
@@ -113,9 +140,10 @@ NULL
 #' chop(1:10, c(2, 5, 8), labels = lbl_dash())
 #'
 #' # floating point inaccuracy:
-#' chop(0.3/3, c(0, 0.1, 0.1, 1))
+#' chop(0.3/3, c(0, 0.1, 0.1, 1), labels = c("< 0.1", "0.1", "> 0.1"))
 #'
-chop <- function (x, breaks, labels,
+chop <- function (x, breaks,
+        labels    = lbl_intervals(),
         extend    = NULL,
         left      = TRUE,
         close_end = FALSE,
@@ -130,14 +158,13 @@ chop <- function (x, breaks, labels,
   breaks <- breaks(x, extend, left, close_end)
   assert_that(is.breaks(breaks), length(breaks) >= 2L)
 
-  if (missing(labels)) labels <- NULL
-  labels <- labels %||% lbl_intervals()
-  if (is.function(labels)) labels <- labels(breaks)
-
-  stopifnot(length(labels) == length(breaks) - 1)
-
   codes <- categorize(x, breaks)
 
+  if (is.null(labels)) return(codes)
+
+  if (is.function(labels)) labels <- labels(breaks)
+  stopifnot(length(labels) == length(breaks) - 1)
+
   real_codes <- if (drop) unique(codes[! is.na(codes)]) else TRUE
   if (anyDuplicated(labels[real_codes])) {
     stop("Duplicate labels found: ", paste(labels, collapse = ", "))
@@ -153,28 +180,28 @@ chop <- function (x, breaks, labels,
 
 #' @rdname chop
 #' @export
-#' @details
-#' `kiru` is a synonym for `chop`. If you load `tidyr`, you can use it to avoid
-#'  confusion with `tidyr::chop()`.
 kiru <- chop
 
 
 #' Chop data precisely (for programmers)
 #'
-#' @inherit chop-doc params return
+#' @inheritParams chop
 #'
 #' @details
 #' `fillet()` calls [chop()] with `extend = FALSE` and `drop = FALSE`. This
 #' ensures that you get only the `breaks` and `labels` you ask for. When
 #' programming, consider using `fillet()` instead of `chop()`.
 #'
+#' @return `fillet()` returns a [`factor`] of the same length as `x`, representing
+#'   the intervals containing the value of `x`.
+#'
 #' @family chopping functions
 #'
 #' @export
 #'
 #' @examples
 #' fillet(1:10, c(2, 5, 8))
-fillet <- function (x, breaks, labels, left = TRUE, close_end = FALSE) {
+fillet <- function (x, breaks, labels = lbl_intervals(), left = TRUE, close_end = FALSE) {
   chop(x, breaks, labels, left = left, close_end = close_end, extend = FALSE,
       drop = FALSE)
 }
@@ -182,13 +209,13 @@ fillet <- function (x, breaks, labels, left = TRUE, close_end = FALSE) {
 
 #' Chop by quantiles
 #'
-#' `chop_quantiles` chops data by quantiles. `chop_equally` chops
-#' data into equal-sized groups. `chop_deciles` is a convenience shortcut and
-#' chops into deciles.
-#'
+#' `chop_quantiles()` chops data by quantiles.
+#' `chop_deciles()` is a convenience shortcut and chops into deciles.
 #'
 #' @param probs A vector of probabilities for the quantiles.
-#' @param ... Passed to [chop()], or for `brk_quantiles` to [stats::quantile()].
+#' @param ... Passed to [chop()], or for `brk_quantiles()` to
+#'   [stats::quantile()].
+#' @inheritParams chop
 #' @inherit chop-doc params return
 #'
 #' @details
@@ -212,8 +239,6 @@ fillet <- function (x, breaks, labels, left = TRUE, close_end = FALSE) {
 #'
 #' chop_deciles(1:10)
 #'
-#' chop_equally(1:10, 5)
-#'
 #' # to label by the quantiles themselves:
 #' chop_quantiles(1:10, 1:3/4, lbl_intervals(raw = TRUE))
 #'
@@ -224,7 +249,6 @@ chop_quantiles <- function(
         left      = is.numeric(x),
         close_end = TRUE
       ) {
-
   chop(x, brk_quantiles(probs), ..., left = left, close_end = close_end)
 }
 
@@ -237,12 +261,21 @@ chop_deciles <- function(x, ...) {
 }
 
 
-#' @rdname chop_quantiles
+#' Chop equal-sized groups
+#'
+#' `chop_equally()` chops `x` into groups with an equal number of elements.
 #'
 #' @param groups Number of groups.
+#' @inheritParams chop
+#' @inherit chop-doc params return
+#'
+#' @family chopping functions
 #'
 #' @export
 #' @order 1
+#' @examples
+#' chop_equally(1:10, 5)
+#'
 chop_equally <- function (x, groups, ..., left = is.numeric(x), close_end = TRUE) {
   chop(x, brk_equally(groups), ..., left = left, close_end = close_end)
 }
@@ -250,11 +283,17 @@ chop_equally <- function (x, groups, ..., left = is.numeric(x), close_end = TRUE
 
 #' Chop by standard deviations
 #'
-#' Intervals of width 1 standard deviation are included on either side of the mean.
-#' The outermost pair of intervals will be shorter if `sd` is not a whole number.
+#' Intervals are measured in standard deviations on either side of the
+#' mean.
 #'
+#' In version 0.7.0, these functions changed to specifying `sds` as a vector.
+#' To chop 1, 2 and 3 standard deviations around the mean, write
+#' `chop_mean_sd(x, sds = 1:3)` instead of `chop_mean_sd(x, sd = 3)`.
 #'
-#' @param sd Positive number: include up to `sd` standard deviations.
+#' @param sds Positive numeric vector of standard deviations.
+#' @param sd  `r lifecycle::badge("deprecated")`
+#'
+#' @inheritParams chop
 #' @inherit chop-doc params return
 #'
 #' @family chopping functions
@@ -267,26 +306,25 @@ chop_equally <- function (x, groups, ..., left = is.numeric(x), close_end = TRUE
 #'
 #' chop(1:10, brk_mean_sd())
 #'
-chop_mean_sd <- function (x, sd = 3, ...) {
-  chop(x, brk_mean_sd(sd), ...)
+#' @importFrom lifecycle deprecated
+chop_mean_sd <- function (x, sds = 1:3,  ..., sd = deprecated()) {
+  chop(x, brk_mean_sd(sds = sds, sd = sd), ...)
 }
 
 
-#' Chop into equal-width intervals
+#' Chop into fixed-width intervals
 #'
-#' `chop_width()` chops `x` into intervals of width `width`. `chop_evenly`
-#' chops `x` into `intervals` intervals of equal width.
+#' `chop_width()` chops `x` into intervals of fixed `width`.
 #'
 #' @param width Width of intervals.
-#' @param start Leftpoint of first interval. By default the smallest finite `x`,
-#'   or if `width` is negative, the largest finite `x`.
+#' @param start Starting point for intervals. By default the smallest
+#'   finite `x` (largest if `width` is negative).
+#' @inheritParams chop
 #' @inherit chop-doc params return
 #'
 #' @details
-#' If `width` is negative, intervals will go downwards from `start`.
-#'
-#' `chop_evenly` sets `close_end = TRUE` by default. `chop_width` sets
-#' `left = FALSE` if width is negative.
+#' If `width` is negative, `chop_width()` sets `left = FALSE` and intervals will
+#' go downwards from `start`.
 #'
 #' @family chopping functions
 #' @seealso [brk_width-for-datetime]
@@ -303,26 +341,29 @@ chop_mean_sd <- function (x, sd = 3, ...) {
 #'
 #' chop(1:10, brk_width(2, 0))
 #'
-#' chop_evenly(0:10, 5)
-#'
-chop_width <- function (x, width, start, ..., left = width > 0) {
+chop_width <- function (x, width, start, ..., left = sign(width) > 0) {
   chop(x, brk_width(width, start), left = left, ...)
 }
 
 
-#' @rdname chop_width
+#' Chop into equal-width intervals
+#'
+#' `chop_evenly()` chops `x` into `intervals` intervals of equal width.
 #'
 #' @param intervals Integer: number of intervals to create.
-#' @param groups Do not use. \lifecycle{deprecated}
+#' @inheritParams chop
+#' @inherit chop-doc params return
+#'
+#' @details `chop_evenly()` sets `close_end = TRUE` by default.
+#'
+#' @family chopping functions
 #'
 #' @export
 #' @order 1
-chop_evenly <- function (x, intervals, ..., groups, close_end = TRUE) {
-  if (! missing(groups)) {
-    lifecycle::deprecate_warn("0.4.0", "chop_evenly(groups = )",
-          with = "chop_evenly(intervals = )")
-    if (missing(intervals)) intervals <- groups
-  }
+#' @examples
+#' chop_evenly(0:10, 5)
+#'
+chop_evenly <- function (x, intervals, ..., close_end = TRUE) {
   chop(x, brk_evenly(intervals), ..., close_end = close_end)
 }
 
@@ -333,6 +374,7 @@ chop_evenly <- function (x, intervals, ..., groups, close_end = TRUE) {
 #' interval may have fewer elements.
 #'
 #' @param n Integer: number of elements in each interval.
+#' @inheritParams chop
 #' @inherit chop-doc params return
 #'
 #' @details
@@ -347,9 +389,7 @@ chop_evenly <- function (x, intervals, ..., groups, close_end = TRUE) {
 #' @family chopping functions
 #'
 #' @examples
-#' table(chop_n(1:10, 5))
-#'
-#' table(chop_n(1:10, 4))
+#' chop_n(1:10, 5)
 #'
 #' # too many duplicates
 #' x <- rep(1:2, each = 3)
@@ -362,4 +402,4 @@ chop_n <- function (x, n, ..., close_end = TRUE) {
   }
 
   res
-}
\ No newline at end of file
+}
